summaryrefslogtreecommitdiffstats
path: root/src/filename.cpp
diff options
context:
space:
mode:
authormueller <mueller@afe2bf4a-e733-0410-8a33-86f594647bc7>1999-12-15 19:29:47 (GMT)
committermueller <mueller@afe2bf4a-e733-0410-8a33-86f594647bc7>1999-12-15 19:29:47 (GMT)
commitdaf91dc906e217e81f77f491e0abf505a91289b8 (patch)
tree223d088e44a6b0956dd0437ed4851244b2e7f36c /src/filename.cpp
parenta6cb7ef1dc7c3d6b6ff949646b9b2deda3fc0bf3 (diff)
downloadDoxygen-daf91dc906e217e81f77f491e0abf505a91289b8.zip
Doxygen-daf91dc906e217e81f77f491e0abf505a91289b8.tar.gz
Doxygen-daf91dc906e217e81f77f491e0abf505a91289b8.tar.bz2
mods for doxygen-0.49-990728
Diffstat (limited to 'src/filename.cpp')
-rw-r--r--src/filename.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/filename.cpp b/src/filename.cpp
index 60367dc..a345969 100644
--- a/src/filename.cpp
+++ b/src/filename.cpp
@@ -26,9 +26,9 @@ FileName::~FileName()
{
}
//static QString convertSlashes(const char *s)
//{
-// QString result=s;
+// QCString result=s;
// int i,l=result.length();
// for (i=0;i<l;i++) if (result.at(i)=='/') result.at(i)='_';
// return result;
@@ -36,7 +36,7 @@ FileName::~FileName()
void FileName::generateDiskNames()
{
- QString commonPrefix;
+ QCString commonPrefix;
FileDef *fd=first();
int count=0;
while (fd) { if (!fd->isReference()) count++; fd=next(); }
@@ -66,8 +66,8 @@ void FileName::generateDiskNames()
//printf("i=%d fd->path=`%s' fd->name=`%s'\n",i,fd->path.data(),fd->name().data());
if (i==(int)fd->path.length())
{
- warning("Warning: Input file found multiple times!\n"
- " The generated documentation for this file may not be correct!\n");
+ warning("Warning: Input file %s found multiple times!\n"
+ " The generated documentation for this file may not be correct!\n",fd->absFilePath().data());
found=TRUE;
}
else if (fd->path[i]!=c)
@@ -26,9 +26,9 @@ FileName::~FileName()
{
}
-//static QString convertSlashes(const char *s)
+//static QCString convertSlashes(const char *s)
//{